properties property

  1. @protected
Map<String, dynamic> get properties

A notifying map view for reading and writing property values by name.

Assigning through this map, for example properties["token"] = value, stores the value and notifies listeners for that property.

Implementation

@protected
Map<String, dynamic> get properties =>
    ChimingProperties(_properties, notifyListeners);