EnhancedValueNotifier<T> class
A EnhancedChangeNotifier that holds a single value.
When value is replaced with something that is not equal to the old value as evaluated by the equality operator ==, this class notifies its listeners.
Limitations
Because this class only notifies listeners when the value's identity changes, listeners will not be notified when mutable state within the value itself changes.
For example, a EnhancedValueNotifier<List<int>> will not notify its listeners
when the contents of the list are changed.
As a result, this class is best used with only immutable data types.
For mutable data types, consider extending EnhancedChangeNotifier directly.
- Inheritance
-
- Object
- ChangeNotifier
- EnhancedChangeNotifier
- EnhancedValueNotifier
- Implemented types
- Implementers
Constructors
- EnhancedValueNotifier(T _value)
- Creates a ChangeNotifier that wraps this value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Override hasListeners to check if there are any listeners.
no setterinherited
-
properties
→ Map<
String, dynamic> -
A notifying map view for reading and writing property values by name.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T
-
The current value stored in this notifier.
getter/setter pairoverride-getter
Methods
-
addListener(
Function listener, {Object? target, bool once = false, bool immediate = false}) → void -
Register a listener for a specific property
target can be an element or elements list like [ property1, property2 ]
inherited
-
dispose(
) → void -
Override dispose to discards any resources used by the object. After
this is called, the object is not in a usable state and should be discarded
(calls to addListener will throw after the object is disposed).
inherited
-
fromMap(
Map< String, dynamic> props) → void -
Initializes stored values from
propswithout notifying listeners.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
[String? target]) → void -
Notify listeners for a specific element
inherited
-
removeListener(
Function listener) → void -
Remove a listener
inherited
-
toString(
) → String -
Returns a debug description containing this object's identity and value.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String target) → dynamic -
Returns the stored value for
target.inherited -
operator []=(
String target, dynamic value) → void -
Stores
valuefortargetand notifies listeners fortarget.inherited